/*
 * Copyright (C) 1998-2001, Neil D. McKay
 */

/*
 * Type XopDrawableGeometry stores the attributes returned
 * by the XGetGeometry call in a convenient form.
 */

typedef struct {
    Window rootwin;			/* Root window for drawable     */
    int x,y;				/* Upper-left corner of window's
					 * border, relative to parent's
					 * origin. (Zero for pixmaps.)  */
    unsigned int width, height;		/* Width and height (duh)       */
    unsigned int border_width, depth;   /* Border width and depth (in
					 * bits) of drawable            */
} XopDrawableGeometry;


/*
 * This structure contains all information related to the
 * Xop command's options.
 */

typedef struct {
    Display *display;		/* Display on which to operate	*/
    Colormap colormap;		/* Colormap to use		*/
    int screenNumber;		/* Screen number for operation	*/
} XopOptions;


/*
 * Declarations of internal functions
 */

/* event.c */
extern int XopParseEvent _ANSI_ARGS_((Tcl_Interp *interp, Display *display, Window recip, XEvent *eventPtr, long *maskPtr, int argc, char **argv));
/* keyboard.c */
extern int XopKeyboardCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
/* misccmd.c */
extern int XopAccessCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopBellCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopBufferCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopEventCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopFontCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopSavesetCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopScreensaverCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopServerCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
/* pointer.c */
extern int XopPointerCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
/* utils.c */
extern int XopGetDrawableId _ANSI_ARGS_((Tcl_Interp *interp, char *str, Drawable *drawablePtr));
extern void XopAppendDrawableId _ANSI_ARGS_((Tcl_Interp *interp, Drawable drawable));
extern int XopGetWindowAttributes _ANSI_ARGS_((Display *display, Window win, XWindowAttributes *attrPtr));
extern int XopGetDrawableGeometry _ANSI_ARGS_((Display *display, Drawable drawable, XopDrawableGeometry *geomPtr));
extern int XopQueryColor _ANSI_ARGS_((Display *display, Colormap colormap, XColor *colorPtr));
extern int XopQueryColors _ANSI_ARGS_((Display *display, Colormap colormap, XColor *colorPtr, int nColors));
extern int XopIsValidWindow _ANSI_ARGS_((Display *display, Window window));
extern int XopIsValidDrawable _ANSI_ARGS_((Display *display, Drawable drawable));
extern int XopIsValidColormap _ANSI_ARGS_((Display *display, Colormap colormap));
extern int XopGetAndCheckWindowId _ANSI_ARGS_((Tcl_Interp *interp, Display *display, char *str, Window *windowPtr));
extern int XopGetAndCheckDrawableId _ANSI_ARGS_((Tcl_Interp *interp, Display *display, char *str, Drawable *drawablePtr));
extern int XopGetAndCheckColormapId _ANSI_ARGS_((Tcl_Interp *interp, Display *display, char *str, Colormap *colormapPtr));
extern Window XopParentXId _ANSI_ARGS_((Display *display, Window w));
extern int XopXErrorHandler _ANSI_ARGS_((ClientData clientData, XErrorEvent *errEventPtr));
/* windraw.c */
extern int XopDrawableCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopWindowCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
/* wm.c */
extern int XopColormapCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopFocusCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
extern int XopWMPropsCommand _ANSI_ARGS_((Tcl_Interp *interp, int argc, char **argv, XopOptions *opts));
